/* AMX Mod X
*
*   Challenge
*
*  This program is free software; you can redistribute it and/or modify it
*  under the terms of the GNU General Public License as published by the
*  Free Software Foundation; either version 2 of the License, or (at
*  your option) any later version.
*
*  This program is distributed in the hope that it will be useful, but
*  WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
*  General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software Foundation, 
*  Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
*
*  In addition, as a special exception, the author gives permission to
*  link the code of this program with the Half-Life Game Engine ("HL
*  Engine") and Modified Game Libraries ("MODs") developed by Valve, 
*  L.L.C ("Valve"). You must obey the GNU General Public License in all
*  respects for all of the code used other than the HL Engine and MODs
*  from Valve. If you modify this file, you may extend this exception
*  to your version of the file, but you are not obligated to do so. If
*  you do not wish to do so, delete this exception statement from your
*  version.
*
*/

#include <amxmodx>
#include <amxmisc>
#include <time>
#include <cstrike>
#include <celltrie>
#include <sqlx>

#define PLUGIN "Challenge"
#define VERSION "1.6.1"
#define AUTHOR "R3X"

#define MAX_GROUPS 10

#define GROUP_LEN 32
#define CHALLENGE_LEN 64
#define AWARD_LEN 32

#if CHALLENGE_LEN >= AWARD_LEN
	#define CHBUF_LEN CHALLENGE_LEN
#else
	#define CHBUF_LEN AWARD_LEN
#endif


#tryinclude <dhud>
#tryinclude <orpheu>
#tryinclude <orpheu_stocks>



#define DATE_FORMAT "%Y-%m-%d %H:%M:%S"

#define MAX_CUSTOM 10

new Handle:gTuple;

new gszUsersTable[64];
new gszStatsTable[64];

new gszQuery[1024];
new const giMax = charsmax(gszQuery);

new gcvarSaveMethod;
new gcvarBots;
new gcvarListAvailable;


new bool:gbLoaded[33];
new giPid[33];
new giPlayedTime[33];
new giFirstConnect[33];
new bool:gbShowInfo[33];


new giWeaponStats[33][31+MAX_CUSTOM][2];
new bool:gbWeaponChanged[33][31+MAX_CUSTOM];
new bool:gbWeapListen[31+MAX_CUSTOM] = {false, ...};

new gfwTupleAvailable;
new gfwGainPoint;
new gfwPIDLoaded;
new gfwDataLoaded;
new gfwPrintInfo;

new gszFile[128];
new giCustomId = CSW_P90+1;

new Trie:gWeaponList;

new Array:gDone[33];
new Array:gChallenges;
new Array:gAwards;
new Array:gForwards;
new Array:gInGroup;

new gcvarUseDhud;
new gcvarPlayersLimit;

new Trie:gGroups;
new gszGroups[MAX_GROUPS][GROUP_LEN];
new giGroupsNum = 0;

new bool:gbDeathMsgRegs = false;

#include "info/dhud_deque.inl"
#include "info/default.inl"


#include "db/sqlite.inl"
#include "db/mysql.inl"
#include "db/shared.inl"
#include "other/challengeList.inl"
#include "other/clcmds.inl"

bool:isValidGame(){
	new iNum = 0;
	new iLimit = get_pcvar_num(gcvarPlayersLimit);
	
	new CsTeams:team;
	for(new id=1; id<33;id++){
		if(iNum >= iLimit) 
			return true;
		
		if(is_user_connected(id)){
			team = cs_get_user_team(id);
			if(team == CS_TEAM_CT || team == CS_TEAM_T)
				iNum++;
		}
	}
	
	return (iNum >= iLimit);
}

getPlayedTime(id){
	if(!isValidGame()) 
		return giPlayedTime[id];
		
	return giPlayedTime[id] + get_user_time(id, 1);
}

addWeaponStat(id, wid, hs=0){
	if(!isValidGame()) 
		return giWeaponStats[id][wid][_:(!!hs)];
	
	new iRet;
	if(ExecuteForward(gfwGainPoint, iRet, id, wid, hs) && iRet == PLUGIN_HANDLED)
		return giWeaponStats[id][wid][_:(!!hs)];
	
	gbWeaponChanged[id][wid] = true;
	
	new ret;
	ret = ++giWeaponStats[id][wid][0];
	if(hs) 
		ret = ++giWeaponStats[id][wid][1];
	
	return ret;
}
clearChallengeStat(id){
	new iSize = ArraySize(gDone[id]);
	for(new i=0;i<iSize; i++)
		ArraySetCell(gDone[id], i, 0);
}
stock SQL_PrepareString(const szQuery[], szOutPut[], size){
	copy(szOutPut, size, szQuery);
	replace_all(szOutPut, size, "'", "\'");
	replace_all(szOutPut,size, "`", "\`");	
	replace_all(szOutPut,size, "\\", "\\\\");
}

public plugin_init() {
	register_plugin(PLUGIN, VERSION, AUTHOR);
	
	register_cvar("amx_challenge_host", "");
	register_cvar("amx_challenge_user", "");
	register_cvar("amx_challenge_pass", "");

	register_cvar("amx_challenge_db", "addons/amxmodx/data/challenge.db");
#if defined R3X_TU_MAJSTRUJE
	register_cvar("amx_challenge_db", "addons/amxmodx/data/codmw2/database.sqlite");
#else
	register_cvar("amx_challenge_prefix", "");
#endif
	register_cvar("amx_challenge_sqltype", "sqlite");
	
	gcvarUseDhud = register_cvar("amx_challenge_usedhud", "1");
	register_cvar("amx_challenge_useorpheu", "0"); 
	
	gcvarPlayersLimit = register_cvar("amx_challenge_minplayers", "0"); 
	
	gcvarSaveMethod = register_cvar("amx_challenge_save", "1");
	
	//Plugin zlicza staty dla botow
	//0 - nie, tylko zywi gracze
	//1 - boty grajace
	//2 - boty grajace+HLTV
	gcvarBots = register_cvar("amx_challenge_bots", "0");
	
	//Czy lista dostepna
	gcvarListAvailable = register_cvar("amx_challenge_list_available", "1");
	
	register_logevent( "eventRoundEnd",2, "1=Round_End");
	
	gChallenges = ArrayCreate(CHALLENGE_LEN);
	ArrayPushString(gChallenges, "");
	
	gInGroup = ArrayCreate();
	ArrayPushCell(gInGroup, -1);
	
	gAwards = ArrayCreate(AWARD_LEN);
	ArrayPushString(gAwards, "");
	
	gForwards = ArrayCreate();
	ArrayPushCell(gForwards, 0);
	
	for(new i=0; i<33; i++){
		gDone[i] = ArrayCreate();
		ArrayPushCell(gDone[i], 0);
	}
	
	gGroups = TrieCreate();
	
	gfwTupleAvailable = CreateMultiForward("forward_tuple", ET_IGNORE, FP_CELL);
	
	gfwPIDLoaded = CreateMultiForward("client_pid_loaded", ET_IGNORE, FP_CELL, FP_CELL);
	
	gfwGainPoint = CreateMultiForward("client_gain_point", ET_CONTINUE ,FP_CELL, FP_CELL, FP_CELL);
	gfwDataLoaded = CreateMultiForward("client_data_loaded", ET_IGNORE, FP_CELL);
	gfwPrintInfo = CreateMultiForward("client_print_info", ET_STOP, FP_CELL, FP_STRING, FP_STRING);
	
	register_dictionary("time.txt");
	
	setupWeaponList();
	loadCustomWeapons();
	
	register_clcmd("say /infooff", "cmdHideinfo");
	register_clcmd("say_team /infooff", "cmdHideinfo");
	register_clcmd("infooff", "cmdHideinfoH");
	
	register_clcmd("say /infoon", "cmdShowinfo");
	register_clcmd("say_team /infoon", "cmdShowinfo");
	register_clcmd("infoon", "cmdShowinfoH");
}

public plugin_cfg(){
	new szType[10];
	get_cvar_string("amx_challenge_sqltype", szType, 9);
	
	new szOld[10];
	SQL_GetAffinity(szOld, 9);
	
	if(equali(szType, "mysql"))
		state mysql;
	else if(equali(szType, "sqlite"))
		state sqlite;
	else
		set_fail_state("Invalid affinity. Must be sqlite or mysql)");
		
	strtolower(szType);
	
	if(!equali(szOld, szType)){
		if(!SQL_SetAffinity(szType))
			log_amx("Failed to set affinity");
	}
			
	new szHost[64], szUser[64], szPass[64], szDB[64], szPrefix[32];
	get_cvar_string("amx_challenge_host", szHost, 63);
	get_cvar_string("amx_challenge_user", szUser, 63);
	get_cvar_string("amx_challenge_pass", szPass, 63);
	get_cvar_string("amx_challenge_db", szDB, 63);
	
	setupDB(szDB);
	
	get_cvar_string("amx_challenge_prefix", szPrefix, 31);
	formatex(gszUsersTable, 63, "%susers", szPrefix);
	formatex(gszStatsTable, 63, "%sstats", szPrefix);
	
	
	gTuple = SQL_MakeDbTuple(szHost, szUser, szPass, szDB, 0);
	if(gTuple == Empty_Handle){
		set_fail_state("Nie mozna utworzyc uchwytu danych!");
		return;
	}		
	
	new iRet;
	ExecuteForward(gfwTupleAvailable, iRet, gTuple);
	
	
	prepareConnection();
	tryCreateTables();
	
	if(get_pcvar_num(gcvarListAvailable)){
		register_clcmd("say /challenge", "cmdList");
		register_clcmd("say_team /challenge", "cmdList");
		
		register_clcmd("challenge", "cmdListH");
		
		set_task(540.0, "taskAnnounce", 34678637, _, _, "b");
	}	
	
#if defined _orpheu_included
	if(get_cvar_num("amx_challenge_useorpheu")){
		new OrpheuFunction:WriteString = OrpheuGetEngineFunction("pfnWriteString","WriteString");
		new OrpheuFunction:MessageBegin = OrpheuGetEngineFunction("pfnMessageBegin","MessageBegin");
		new OrpheuFunction:MessageEnd = OrpheuGetEngineFunction("pfnMessageEnd","MessageEnd");
		new OrpheuFunction:WriteByte = OrpheuGetEngineFunction("pfnWriteByte","WriteByte");
		
		OrpheuRegisterHook(WriteString,"WriteStringf",OrpheuHookPre);
		OrpheuRegisterHook(MessageBegin,"MessageBeginf",OrpheuHookPre);
		OrpheuRegisterHook(MessageEnd,"MessageEndf",OrpheuHookPost);
		OrpheuRegisterHook(WriteByte,"WriteBytef",OrpheuHookPre);
	}else{
		if(!gbDeathMsgRegs)
			register_event("DeathMsg", "eventDeathMsg", "a");
		gbDeathMsgRegs = true;
	}
#else
	if(!gbDeathMsgRegs)
		register_event("DeathMsg", "eventDeathMsg", "a");
	gbDeathMsgRegs = true;
#endif
	//Check is DHUD loaded
	printInfoDHUD(0, "", "");
}

public plugin_end(){
	SQL_FreeHandle(gTuple);
	TrieDestroy(gWeaponList);
}

public plugin_natives(){
	set_native_filter("native_filter");
	
	register_library("Challenge");
	
	register_native("register_challenge", "_register_challenge");
	register_native("challenge_custom_weapon", "_challenge_custom_weapon");
	register_native("challenge_uses_stats", "_challenge_uses_stats");
	register_native("ch_get_user_stats", "_ch_get_user_stats");
	register_native("ch_add_user_stats", "_ch_add_user_stats");
	register_native("ch_set_user_stats", "_ch_set_user_stats");
	register_native("ch_get_user_played_time", "_ch_get_user_played_time");
	register_native("ch_get_user_first_connect", "_ch_get_user_first_connect");
	register_native("challenge_set_group", "_challenge_set_group");
	
	
	
	register_native("challenge_get_state", "_challenge_get_state");
	register_native("challenge_done", "_challenge_done");
	register_native("challenge_show_custom_info", "_challenge_show_custom_info");
}

public native_filter(const szNative[], index, trap){
	if(trap == 0)
		return PLUGIN_HANDLED;
	else{
		if(contain(szNative, "DHUD_") == 0){
			set_cvar_num("amx_challenge_usedhud", 0);
			return PLUGIN_HANDLED;
		}
		
		if(contain(szNative, "Orpheu") == 0){
			set_cvar_num("amx_challenge_useorpheu", 0);
			
			if(!gbDeathMsgRegs)
				register_event("DeathMsg", "eventDeathMsg", "a");
			gbDeathMsgRegs = true;
			return PLUGIN_HANDLED;
		}
	}
	return PLUGIN_CONTINUE;
}

setupWeaponList(){
	gWeaponList = TrieCreate();
	TrieSetCell(gWeaponList, "p228", CSW_P228);
	TrieSetCell(gWeaponList, "scout", CSW_SCOUT);
	TrieSetCell(gWeaponList, "grenade", CSW_HEGRENADE);
	TrieSetCell(gWeaponList, "xm1014", CSW_XM1014);
	TrieSetCell(gWeaponList, "mac10", CSW_MAC10);
	TrieSetCell(gWeaponList, "aug", CSW_AUG);
	TrieSetCell(gWeaponList, "elite", CSW_ELITE);
	TrieSetCell(gWeaponList, "fiveseven", CSW_FIVESEVEN);
	TrieSetCell(gWeaponList, "ump45", CSW_UMP45);
	TrieSetCell(gWeaponList, "sg550", CSW_SG550);
	TrieSetCell(gWeaponList, "galil", CSW_GALIL);
	TrieSetCell(gWeaponList, "famas", CSW_FAMAS);
	TrieSetCell(gWeaponList, "usp", CSW_USP);
	TrieSetCell(gWeaponList, "glock18", CSW_GLOCK18);
	TrieSetCell(gWeaponList, "awp", CSW_AWP);
	TrieSetCell(gWeaponList, "mp5navy", CSW_MP5NAVY);
	TrieSetCell(gWeaponList, "m249", CSW_M249);
	TrieSetCell(gWeaponList, "m3", CSW_M3);
	TrieSetCell(gWeaponList, "m4a1", CSW_M4A1);
	TrieSetCell(gWeaponList, "tmp", CSW_TMP);
	TrieSetCell(gWeaponList, "g3sg1", CSW_G3SG1);
	TrieSetCell(gWeaponList, "deagle", CSW_DEAGLE);
	TrieSetCell(gWeaponList, "sg552", CSW_SG552);
	TrieSetCell(gWeaponList, "ak47", CSW_AK47);
	TrieSetCell(gWeaponList, "knife", CSW_KNIFE);
	TrieSetCell(gWeaponList, "p90", CSW_P90);
}



trySelectPid(id, const szField[], const szAuth[]){
	formatex(gszQuery, giMax, "SELECT id, firstConnect, playedTime  FROM `%s` WHERE %s = '%s'",
			gszUsersTable, szField, szAuth);
	
	new data[1];
	data[0] = id;
	SQL_ThreadQuery(gTuple, "handleSelectQuery", gszQuery, data, sizeof(data));
}

public client_connect(id){
	gbLoaded[id] = false;
	giPid[id] = 0;
	gbShowInfo[id] = true;
	
	clearChallengeStat(id);
}
public client_disconnect(id){
	if(gbLoaded[id]){
		saveData(id);
	}
}
public client_putinserver(id){
	clearWeaponStats(id);
	
	switch(get_pcvar_num(gcvarBots)){
		case 2:{}
		case 1: {
			if(is_user_hltv(id)) return;
		}
		default:{
			if(is_user_bot(id) || is_user_hltv(id)) return;
		}
	}
	
	new szAuth[64], szField[32];
	switch(get_pcvar_num(gcvarSaveMethod)){
		case 3:{
			get_user_ip(id, szAuth, 31, 1);
			copy(szField, 31, "ip");
		}
		case 2:{
			get_user_name(id, szAuth, 31);
			SQL_PrepareString(szAuth, szAuth, 63);
			copy(szField, 31, "nickname");
		}
		default:{
			get_user_authid(id, szAuth, 31);
			copy(szField, 31, "steamid");
		}
	}
	trySelectPid(id, szField, szAuth);
}

public client_authorized_sql(id, pid){
	giPid[id] = pid;
	loadWeaponStats(id);
	
	new iRet;
	ExecuteForward(gfwPIDLoaded, iRet, id, pid);
}
clearWeaponStats(id){
	for(new i=0;i<31+MAX_CUSTOM;i++){
		giWeaponStats[id][i][0] = 0;
		giWeaponStats[id][i][1] = 0;
	}
}


saveData(id){
	if(gbLoaded[id]){
		savePlayedTime(id);
		saveWeaponData(id);
	}
}

public eventRoundEnd(){
	for(new id=1;id<33;id++){
		if(is_user_connected(id))
			saveData(id);
			
		for(new j=1;j<31;j++)
			gbWeaponChanged[id][j] = false;
	}
}
deathNotice(killer, victim, hs, const szWeapon[]){
	if(!is_user_connected(killer))
		return;
		
	new wid;
	if(!TrieGetCell(gWeaponList, szWeapon, wid) || !gbWeapListen[wid])
		return;
	if(cs_get_user_team(victim) == cs_get_user_team(killer))
		return;
	addWeaponStat(killer, wid, hs);
}



//Natives
validWeapon(wid){
	return (wid > 0 && wid <= (CSW_P90+MAX_CUSTOM));
}

public _register_challenge(plugin, params){
	if(params < 2)
		return 0;
		
	new szTemp[CHBUF_LEN];
	get_string(1, szTemp, CHALLENGE_LEN-1);
	ArrayPushString(gChallenges, szTemp);
	
	get_string(2, szTemp, AWARD_LEN-1)
	ArrayPushString(gAwards, szTemp);
	
	new fw = CreateOneForward(plugin, "challenge_progress", FP_CELL, FP_CELL, FP_ARRAY, FP_CELL);
	ArrayPushCell(gForwards, fw);
	
	for(new i=0; i<33; i++){
		ArrayPushCell(gDone[i], 0);
	}
	
	ArrayPushCell(gInGroup, -1);
	
	return ArraySize(gAwards)-1;
}
public _challenge_custom_weapon(plugin, params){
	if(params < 1)
		return 0;
	
	new szName[32];
	get_string(1, szName, 31);
	
	return pushCustomWeapon(szName);
}
public _challenge_uses_stats(plugin, params){
	if(params < 1)
		return 0;
	
	new wid = get_param(1);
	if(validWeapon(wid))
	{
		gbWeapListen[wid] = true;
		return 1;
	}
	return 0;
}

public _ch_get_user_stats(plugin, params){
	if(params < 3)
		return 0;
	
	new id = get_param(1);
	if(!is_user_connected(id))
		return 0;
	
	new wid = get_param(2);
	if(!validWeapon(wid))
		return 0;
		
	new hs = !!get_param(3);
	return giWeaponStats[id][wid][hs];
}
public _ch_set_user_stats(plugin, params){
	if(params < 4)
		return 0;
	
	new id = get_param(1);
	if(!is_user_connected(id))
		return 0;
	
	new wid = get_param(2);
	if(!validWeapon(wid))
		return 0;
		
	new hs = !!get_param(3);
	giWeaponStats[id][wid][hs] = max(0, get_param(4));
	gbWeaponChanged[id][wid] = true;
	return 1;
}
public _ch_add_user_stats(plugin, params){
	if(params < 3)
		return 0;
		
	new id = get_param(1);
	if(!is_user_connected(id))
		return 0;
	
	new wid = get_param(2);
	if(!validWeapon(wid))
		return 0;
		
	new hs = !!get_param(3);
	
	return addWeaponStat(id, wid, hs);
}

public _ch_get_user_played_time(plugin, params){
	if(params < 1)
		return 0;
		
	new id = get_param(1);
	if(!is_user_connected(id))
		return 0;
	return getPlayedTime(id);
}

public _ch_get_user_first_connect(plugin, params){
	if(params < 1)
		return 0;
		
	new id = get_param(1);
	if(!is_user_connected(id))
		return 0;
		
	return giFirstConnect[id];
}
public _challenge_get_state(plugin, params){
	if(params < 2)
		return 0;
		
	new id = get_param(1);
	if(!is_user_connected(id))
		return 0;
		
	new chid = get_param(2);
	if(chid < 1 || chid >= ArraySize(gAwards))
		return 0;
		
	return ArrayGetCell(gDone[id], chid);
}

public _challenge_done(plugin, params){
	if(params < 3)
		return 0;
	new id = get_param(1);
	if(!is_user_connected(id))
		return 0;
	
	new chid = get_param(2);
	if(chid < 1 || chid >= ArraySize(gAwards))
		return 0;
	
	ArraySetCell(gDone[id], chid, 1);
	
	if(gbShowInfo[id] && get_param(3)){
		new szChallenge[CHALLENGE_LEN];
		ArrayGetString(gChallenges, chid, szChallenge, CHALLENGE_LEN-1);
		
		new szAward[AWARD_LEN];
		ArrayGetString(gAwards, chid, szAward, AWARD_LEN);
		
		printInfo(id, szChallenge, szAward);
	}
		
	return 1;
}
public _challenge_show_custom_info(plugin, params){
	if(params < 3)
		return 0;
		
	new id = get_param(1);
	if(!is_user_connected(id))
		return 0;
	new szChallenge[CHALLENGE_LEN];
	get_string(2, szChallenge, CHALLENGE_LEN-1);
	
	new szAward[AWARD_LEN];
	get_string(3, szAward, AWARD_LEN-1);
	
	new iColor[3] = {255, 255, 255};
	
	if(params >= 4){
		get_array(4, iColor, 3);
	}
	
	if(gbShowInfo[id])
		return printInfo(id, szChallenge, szAward, iColor);
	return 0;
}

public _challenge_set_group(plugin, params){
	if(params < 2)
		return 0;
		
	new challenge = get_param(1);
	if(challenge <= 0 || challenge >= ArraySize(gInGroup))
		return 0;
		
	new szGroup[GROUP_LEN];
	get_string(2, szGroup, GROUP_LEN-1);
	
	new group;
	if(!TrieGetCell(gGroups, szGroup, group)){
		copy(gszGroups[giGroupsNum], GROUP_LEN-1, szGroup);
		TrieSetCell(gGroups, szGroup, giGroupsNum);
		group = giGroupsNum++;
	}
	
	ArraySetCell(gInGroup, challenge, group);
	return 1;
}
//Customs
loadCustomWeapons(){
	static bool:loaded = false;
	
	if(loaded) return;
	loaded = true;
	
	get_configsdir(gszFile, 127);
	add(gszFile, 127, "/custom_weapons.txt");
	
	if(!file_exists(gszFile)) return;
	
	new szLine[64], iLen;
	
	for(new i=0; read_file(gszFile, i, szLine, 63, iLen); i++){
		trim(szLine);
		if(szLine[0] != ';')
			pushCustomWeapon(szLine, 0);
	}
}

pushCustomWeapon(const szName[], wfile = 1){
	loadCustomWeapons();
	
	new wid;
	if(TrieGetCell(gWeaponList, szName, wid))
		return wid;
	
	if(giCustomId >= CSW_P90+MAX_CUSTOM){
		log_error(AMX_ERR_BOUNDS, "Przekroczono limit niestandardowych broni (%d)", MAX_CUSTOM);
		return 0;
	}
	
	if(szName[0]){
		TrieSetCell(gWeaponList, szName, giCustomId++);
		if(wfile) write_file(gszFile, szName);
	}
	return giCustomId-1;
}

//Orpheu Region
enum{
	FORWARD_NONE,
	FORWARD_KILLER,
	FORWARD_VICTIM,
	FORWARD_HS,
	FORWARD_WEAPON,
	FORWARD_END
};


new _giForward = FORWARD_NONE;

new _giKiller;
new _giVictim;
new bool:_gbHS;
new _gszWeapon[32];

public OrpheuHookReturn:WriteBytef(iValue){	
	switch(_giForward){
		case FORWARD_KILLER:{
			_giKiller = iValue;
			_giForward = FORWARD_VICTIM;
		}
		case FORWARD_VICTIM:{
			_giVictim = iValue;
			_giForward = FORWARD_HS;
		}
		case FORWARD_HS:{
			_gbHS = !!iValue;
			_giForward = FORWARD_WEAPON;
		}
	}
	return OrpheuIgnored;
}
public OrpheuHookReturn:WriteStringf(const szString[]){
	if(_giForward != FORWARD_WEAPON)
		return OrpheuIgnored;
		
	copy(_gszWeapon, charsmax(_gszWeapon), szString);
	_giForward = FORWARD_END;
	return OrpheuIgnored;
}
public OrpheuHookReturn:MessageBeginf(msg_dest, msg_type, const Float:vfOrigin[], id){
	static DeathMsg = 0;
	if(!DeathMsg) DeathMsg = get_user_msgid("DeathMsg");
	
	if(msg_type != DeathMsg)
		return OrpheuIgnored;

	_giForward = FORWARD_KILLER;
	return OrpheuIgnored;
}
public OrpheuHookReturn:MessageEndf(){
	
	
	if(_giForward == FORWARD_END){
		//log_amx("DeathMsg z Orpheu");
		deathNotice(_giKiller, _giVictim, _gbHS, _gszWeapon);
		_giForward = FORWARD_NONE;
	}
	return OrpheuIgnored;
}

//Standard Region
public eventDeathMsg(){
	new killer = read_data(1);
	new victim = read_data(2);
	new hs = read_data(3);
	new szWeapon[32];
	read_data(4, szWeapon, 31);
	
	//log_amx("DeathMsg z Core");
	deathNotice(killer, victim, hs, szWeapon);
	return PLUGIN_CONTINUE;
}

printInfo(id, const szChallenge[], const szAward[], const iColor[] = {255, 255, 255}){
	if(get_pcvar_num(gcvarUseDhud))
		return printInfoDHUD(id, szChallenge, szAward, iColor);
	else
		printInfoDefault(id, szChallenge, szAward);
	return 0;
}
/* AMXX-Studio Notes - DO NOT MODIFY BELOW HERE
*{\\ rtf1\\ ansi\\ deff0{\\ fonttbl{\\ f0\\ fnil Tahoma;}}\n\\ viewkind4\\ uc1\\ pard\\ lang1045\\ f0\\ fs16 \n\\ par }
*/
