/**
 * Challenge 1.5.1
 */
 
#if defined _challenge_included
  #endinput
#endif
#define _challenge_included

#pragma library "Challenge"


/**
 * Dodaje wyzwanie do listy, umozliwia tez wykorzystanie wbudowanego systemu informowania o osiagach
 * Parametry to slowny opis wyzwania.	
 *
 *	szChallenge	warunki do spelnienia
 *	szAward		nagroda
 *
 *	zwraca id wyzwania (>0)
 */
native register_challenge(const szChallenge[], const szAward[]);


/**
 * Dodaje wyzwanie do grupy zbiorczej
 *
 *	chid		id wyzwania, zwracane przez register_challenge
 *	szGroup		Nazwa grupy
 */
native challenge_set_group(chid, const szGroup[]);

/**
 * Sprawdza czy gracz wykonal zadanie na podstawie tego czy uzyto na nim
 * challenge_done(id, chid)
 *	
 *	id		id gracza
 *	chid		id wyzwania, zwracane przez register_challenge
 */
native challenge_get_state(id, chid);

/**
 * Zapisuje wyzwanie jako zdobyte i ew. wyswietla komunikat o nagrodzie za wyzwanie na podstawie jego id
 *	
 *	id		id gracza
 *	chid		id wyzwania, zwracane przez register_challenge
 *	showinfo	czy pokazywac info
 */
native challenge_done(id, chid, showinfo = 1);

/**
 * Wyswietla komunikat o nagrodzie za wyzwanie
 */
native challenge_show_custom_info(id, const szChallenge[], const szAward[], const iColor[3] = {255, 255, 255});

/**
 * Rejestruje niestandardowa bron, ktora dodal na serwer inny plugin/modul.
 * Zbieranie informacji jest mozliwe jesli:
 *	- DeathMsg jest wysylany globalnie (emessagebegin)
 *	- zabicie za pomoca bytu lub hamsandwich (Ham_TakeDamage)
 *	
 *	szKillName	nazwa z DeathMsg, 
 * 			X killed Y with <szKillName>
 *
 *	zwraca umowne wid dla tej broni
 */
native challenge_custom_weapon(const szKillName[]);

/**
 * Wlacza gromadzenie statystyk dla danej broni
 *
 *	wid		id broni CSW_*
 */
native challenge_uses_stats(wid);

/**
 * Pobiera statystyki gracza z danej broni
 *
 *	id		index gracza
 *	wid		id broni CSW_*
 *	hs		hs 1|0
 */
native ch_get_user_stats(id, wid, hs = 0);

/**
 * Zwiksza o 1 statystyki gracza z danej broni
 *
 *	id		index gracza
 *	wid		id broni CSW_*
 *	hs		hs 1|0
 */
native ch_add_user_stats(id, wid, hs = 0);

/**
 * Ustawia statystyki gracza z danej broni
 *
 *	id		index gracza
 *	wid		id broni CSW_*
 *	hs		hs 1|0
 *	stats		nowa wartosc
 */
native ch_set_user_stats(id, wid, hs = 0, stats);

/**
 * Pobiera ilosc granych sekund na serwerze
 *
 *	id		index gracza
 */
native ch_get_user_played_time(id);

/**
 * Pobiera znacznik czasu pierwszego polaczenia
 *
 *	id		index gracza
 */
native ch_get_user_first_connect(id);

/**
 * Pobiera czas od pierwszego polaczenia do teraz
 *
 *	id		index gracza
 */
stock ch_get_user_joined_time(id){
	new iTime = ch_get_user_first_connect(id);
	if(!iTime)
		return 0;
	return get_systime() - iTime;
}

/**
 * Wywolywane kiedy potrzebny jest postep wyzwania
 *	id			index gracza
 *	challenge		index wyzwania, trzeba sprawdzic czy to nasz
 *	szProgress[], size	string do wpisania wartosci
 *	
 */
forward challenge_progress(id, challenge, szProgress[], size);

/**
 * Wywoywany kiedy wczytane zostan dane gracza zaraz po wejciu na serwer
 * przed tym zdarzeniem ch_get_user_stats nie bdzie dziaa prawidowo
 *
 *	id			index gracza
 */
forward client_data_loaded(id);

/**
 * Informuje o przyznaniu punktu z danej broni
 *
 *	id			index gracza
 *	wid			id broni
 *	hs			1 jesli byl headshot
 *
 *	zwrocenie PLUGIN_HANDLED blokuje przyznanie punktu
 */
forward client_gain_point(id, wid, hs);


/**
 * Umozliwia nadpisanie standardowego wyswietlania info o nagrodzie
 *
 *	id			index gracza
 *	szChallenge		opis wyzwania
 *	szAward			opis nagrody
 *
 *	zwrocenie PLUGIN_HANDLED blokuje standardowy napis
 */
forward client_print_info(id, const szChallenge[], const szAward[]);



forward client_pid_loaded(id, pid);

forward forward_tuple(Handle:Tuple);
/* AMXX-Studio Notes - DO NOT MODIFY BELOW HERE
*{\\ rtf1\\ ansi\\ deff0{\\ fonttbl{\\ f0\\ fnil Tahoma;}}\n\\ viewkind4\\ uc1\\ pard\\ lang1045\\ f0\\ fs16 \n\\ par }
*/
